@@ -1,9 +1,7 @@
 package MooseX::AttributeHelpers::Number;
 use Moose;
 
-our $VERSION   = '0.23';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
+our $VERSION = '0.25';
 
 extends 'Moose::Meta::Attribute';
 with 'MooseX::AttributeHelpers::Trait::Number';
@@ -17,14 +15,22 @@ sub register_implementation { 'MooseX::AttributeHelpers::Number' }
 
 1;
 
+__END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 MooseX::AttributeHelpers::Number
 
+=head1 VERSION
+
+version 0.25
+
 =head1 SYNOPSIS
-  
+
   package Real;
   use Moose;
   use MooseX::AttributeHelpers;
@@ -48,12 +54,16 @@ MooseX::AttributeHelpers::Number
   my $real = Real->new();
   $real->add(5); # same as $real->integer($real->integer + 5);
   $real->sub(2); # same as $real->integer($real->integer - 2);  
-  
+
 =head1 DESCRIPTION
 
 This provides a simple numeric attribute, which supports most of the
 basic math operations.
 
+=head1 NAME
+
+MooseX::AttributeHelpers::Number
+
 =head1 METHODS
 
 =over 4
@@ -103,23 +113,28 @@ Sets the current value of the attribute to its absolute value.
 
 =back
 
-=head1 BUGS
+=head1 SUPPORT
 
-All complex software has bugs lurking in it, and this module is no 
-exception. If you find a bug please either email me, or add the bug
-to cpan-RT.
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=MooseX-AttributeHelpers>
+(or L<bug-MooseX-AttributeHelpers@rt.cpan.org|mailto:bug-MooseX-AttributeHelpers@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://lists.perl.org/list/moose.html>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#moose> on C<irc.perl.org>|irc://irc.perl.org/#moose>.
 
 =head1 AUTHOR
 
+Stevan Little <stevan@iinteractive.com>
+
 Robert Boone
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2009 by Infinity Interactive, Inc.
+This software is copyright (c) 2007 by Stevan Little and Infinity Interactive, Inc.
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
