@@ -2,9 +2,7 @@ package MooseX::AttributeHelpers::Trait::Bool;
 use Moose::Role;
 use MooseX::AttributeHelpers::MethodProvider::Bool;
 
-our $VERSION   = '0.23';
-$VERSION = eval $VERSION;
-our $AUTHORITY = 'cpan:STEVAN';
+our $VERSION = '0.25';
 
 with 'MooseX::AttributeHelpers::Trait::Base';
 
@@ -36,14 +34,22 @@ no Moose::Role;
 
 1;
 
+__END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-MooseX::AttributeHelpers::Bool
+MooseX::AttributeHelpers::Trait::Bool
+
+=head1 VERSION
+
+version 0.25
 
 =head1 SYNOPSIS
-  
+
   package Room;
   use Moose;
   use MooseX::AttributeHelpers;
@@ -66,7 +72,7 @@ MooseX::AttributeHelpers::Bool
   $room->darken;         # same as $room->is_lit(0);
   $room->flip_switch;    # same as $room->is_lit(not $room->is_lit);
   return $room->is_dark; # same as !$room->is_lit
-  
+
 =head1 DESCRIPTION
 
 This provides a simple boolean attribute, which supports most of the
@@ -113,23 +119,28 @@ Equivalent of 'not C<$value>'.
 
 =back
 
-=head1 BUGS
+=head1 SUPPORT
 
-All complex software has bugs lurking in it, and this module is no 
-exception. If you find a bug please either email me, or add the bug
-to cpan-RT.
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=MooseX-AttributeHelpers>
+(or L<bug-MooseX-AttributeHelpers@rt.cpan.org|mailto:bug-MooseX-AttributeHelpers@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://lists.perl.org/list/moose.html>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#moose> on C<irc.perl.org>|irc://irc.perl.org/#moose>.
 
 =head1 AUTHOR
 
+Stevan Little <stevan@iinteractive.com>
+
 Jason May
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2009 by Infinity Interactive, Inc.
+This software is copyright (c) 2007 by Stevan Little and Infinity Interactive, Inc.
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
